/*
 * @adonisjs/http-server
 *
 * (c) AdonisJS
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { AppFactory } from '@adonisjs/application/factories';
import { EncryptionFactory } from '@adonisjs/encryption/factories';
import { Router } from '../src/router/main.js';
import { QsParserFactory } from './qs_parser_factory.js';
/**
 * Router factory is used to generate router class instances for
 * testing
 */
export class RouterFactory {
    #parameters = {};
    /**
     * Returns an instance of the application class
     */
    #getApp() {
        return (this.#parameters.app || new AppFactory().create(new URL('./app/', import.meta.url), () => { }));
    }
    /**
     * Returns an instance of the encryptor to encrypt
     * signed URLs
     */
    #createEncryption() {
        return this.#parameters.encryption || new EncryptionFactory().create();
    }
    /**
     * Merge factory params
     */
    merge(params) {
        Object.assign(this.#parameters, params);
        return this;
    }
    /**
     * Create router instance
     */
    create() {
        return new Router(this.#getApp(), this.#createEncryption(), new QsParserFactory().create());
    }
}
