/*
 * @adonisjs/http-server
 *
 * (c) AdonisJS
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import { moduleImporter } from '@adonisjs/fold';
/**
 * Converts a middleware name and its lazy import to a factory function. The function
 * can than later be used to reference the middleware with different arguments
 * every time.
 */
function middlewareReferenceBuilder(name, middleware) {
    const handler = moduleImporter(middleware, 'handle').toHandleMethod();
    return function (...args) {
        return {
            name,
            args: args[0],
            ...handler,
        };
    };
}
/**
 * Define an collection of named middleware. The collection gets converted
 * into a collection of factory functions. Calling the function returns
 * a reference to the executable middleware.
 */
export function defineNamedMiddleware(collection) {
    return Object.keys(collection).reduce((result, key) => {
        result[key] = middlewareReferenceBuilder(key, collection[key]);
        return result;
    }, {});
}
