/*
 * @adonisjs/http-server
 *
 * (c) AdonisJS
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import Macroable from '@poppinss/macroable';
import { Route } from './route.js';
/**
 * Brisk routes exposes the API to configure the route handler by chaining
 * one of the pre-defined methods.
 *
 * For example: Instead of defining the redirect logic as a callback, one can
 * chain the `.redirect` method.
 *
 * Brisk routes are always registered under the `GET` HTTP method.
 */
export class BriskRoute extends Macroable {
    /**
     * Route pattern
     */
    #pattern;
    /**
     * Matchers inherited from the router
     */
    #globalMatchers;
    /**
     * Reference to the AdonisJS application
     */
    #app;
    /**
     * Middleware registered on the router
     */
    #routerMiddleware;
    /**
     * Reference to route instance. Set after `setHandler` is called
     */
    route = null;
    constructor(app, routerMiddleware, options) {
        super();
        this.#app = app;
        this.#routerMiddleware = routerMiddleware;
        this.#pattern = options.pattern;
        this.#globalMatchers = options.globalMatchers;
    }
    /**
     * Set handler for the brisk route
     */
    setHandler(handler) {
        this.route = new Route(this.#app, this.#routerMiddleware, {
            pattern: this.#pattern,
            globalMatchers: this.#globalMatchers,
            methods: ['GET', 'HEAD'],
            handler: handler,
        });
        return this.route;
    }
    /**
     * Redirects to a given route. Params from the original request will
     * be used when no custom params are defined.
     */
    redirect(identifier, params, options) {
        return this.setHandler(async function redirectsToRoute(ctx) {
            const redirector = ctx.response.redirect();
            if (options?.status) {
                redirector.status(options.status);
            }
            return redirector.toRoute(identifier, params || ctx.params, options);
        });
    }
    /**
     * Redirect request to a fixed URL
     */
    redirectToPath(url, options) {
        return this.setHandler(async function redirectsToPath(ctx) {
            const redirector = ctx.response.redirect();
            if (options?.status) {
                redirector.status(options.status);
            }
            return redirector.toPath(url);
        });
    }
}
