/*
 * @adonisjs/http-server
 *
 * (c) AdonisJS
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import * as errors from '../../exceptions.js';
/**
 * Route finder is used to find a route by its name, route pattern
 * or the controller.method name.
 */
export class RouteFinder {
    #routes;
    constructor(routes) {
        this.#routes = routes;
    }
    /**
     * Find a route by indentifier
     */
    find(routeIdentifier) {
        return (this.#routes.find(({ name, pattern, handler }) => {
            if (name === routeIdentifier || pattern === routeIdentifier) {
                return true;
            }
            if (typeof handler === 'function') {
                return false;
            }
            return handler.reference === routeIdentifier;
        }) || null);
    }
    /**
     * Find a route by indentifier or fail
     */
    findOrFail(routeIdentifier) {
        const route = this.find(routeIdentifier);
        if (!route) {
            throw new errors.E_CANNOT_LOOKUP_ROUTE([routeIdentifier]);
        }
        return route;
    }
    /**
     * Find if a route exists
     */
    has(routeIdentifier) {
        return !!this.find(routeIdentifier);
    }
}
