import Macroable from '@poppinss/macroable';
import type { Application } from '@adonisjs/application';
import { Route } from './route.js';
import type { Constructor, LazyImport } from '../types/base.js';
import type { ParsedGlobalMiddleware } from '../types/middleware.js';
import type { ResourceActionNames, RouteMatcher, RouteMatchers } from '../types/route.js';
/**
 * Route resource exposes the API to register multiple routes for a resource.
 */
export declare class RouteResource extends Macroable {
    #private;
    /**
     * A collection of routes instances that belongs to this resource
     */
    routes: Route[];
    constructor(app: Application<any>, routerMiddleware: ParsedGlobalMiddleware[], options: {
        resource: string;
        controller: string | LazyImport<Constructor<any>> | Constructor<any>;
        globalMatchers: RouteMatchers;
        shallow: boolean;
    });
    /**
     * Register only given routes and remove others
     */
    only(names: ResourceActionNames[]): this;
    /**
     * Register all routes, except the one's defined
     */
    except(names: ResourceActionNames[]): this;
    /**
     * Register api only routes. The `create` and `edit` routes, which
     * are meant to show forms will not be registered
     */
    apiOnly(): this;
    /**
     * Define matcher for params inside the resource
     */
    where(key: string, matcher: RouteMatcher | string | RegExp): this;
    /**
     * Tap into multiple routes to configure them by their name
     */
    tap(callback: (route: Route) => void): this;
    tap(actions: ResourceActionNames | ResourceActionNames[], callback: (route: Route) => void): this;
    /**
     * Set the param name for a given resource
     */
    params(resources: {
        [resource: string]: string;
    }): this;
    /**
     * Prepend name to all the routes
     */
    as(name: string, normalizeName?: boolean): this;
}
